Param
(
$LogFilePath,
$FolderPath
)
#Param
#####################################################################################################
##Report server uri.
$reportServerUri = "http://<Server Name>/ReportServer/ReportService2010.asmx"
##Shared data source parent folder path - relative path
$DatasourceLibrary = "/path of shared datasource library/"
##Shared Datasets parent folder path
$DatasetLibrary = "/path of shared dataset library/"
##Set credentials that need to be used to deploy the reports to report server. 
##This need not be necessary same as that of  the logged in user.
$secpasswd = ConvertTo-SecureString password for domain\username" -AsPlainText -Force
$mycreds = New-Object System.Management.Automation.PSCredential (domain\username, $secpasswd)
#####################################################################################################
$logfile = $LogFilePath
"-------------------------Start of Generic Powershell to deploy SSRS reports to Report server---------------------------------" |  out-file -Filepath $logfile -append

$isSuccess = 1
$CurrentFolder =  split-path  ( $FolderPath  )-Leaf 
Try
{

$rs = New-WebServiceProxy -Uri $ReportServerUri -Credential $mycreds  ;
 if ($?)
    {
$warnings = $null
    }
else
    {
$error[0].Exception  | out-file -Filepath $logfile -append
$isSuccess = 0
    }

}
Catch
{
"Error: $_.Exception.Message"  | out-file -Filepath $logfile -append
$isSuccess = 0
Break
}
# iterate folders from the parent folder to deploy the reports to sharepoint.
$rdlfiles = Get-ChildItem  $FolderPath -Recurse | where-object {$_.extension  -eq ".rdl"}

if ($rdlfiles)
{
  # deploying many reports so iterate through the files
  foreach($rdlfile in $rdlfiles.FullName) 
  {
  # get folder name from the relative path to which we need to deploy the reports. The folder should already be present on target server 
    $relativePath = Get-Item $rdlfile | Resolve-Path -Relative
    $LocalReportreference = $rdlfile
    $reportFileInfo = Get-Item ($LocalReportreference);
    $reportName = $reportFileInfo.Name;	

"-------------------------Start of $reportName--------------------------------------" |  out-file -Filepath $logfile -append

    $relativePath.Substring( $relativePath.IndexOf($CurrentFolder) + $CurrentFolder.Length   ) 
    $targetFolderName =  $relativePath.Substring( $relativePath.IndexOf($CurrentFolder) + $CurrentFolder.Length   ) | split-path  -Parent 

    $targetFolderName = $targetFolderName.Replace("\","/")
    $reportName = $reportName.Replace(".rdl","")
  # set target server path as per the folder in which report is present on file system
    $targetreportLibrary =  $targetFolderName 
   #Load the RDL Xml 
    [xml] $reportXml = Get-Content ($LocalReportreference);	
    [Byte[]]$reportContent = Get-Content $LocalReportreference -Encoding byte 
      "Deploying report $reportName to $targetreportLibrary ..."  | out-file -Filepath $logfile -append
       Try 
          {
           Try{
           $rs.DeleteItem("$targetreportLibrary/$reportName") 
 		}
	   Catch
		{
            $Message  =  $_.Exception.Message 
            $Message  | out-file -Filepath $logfile -append
		}
           $item = $rs.CreateCatalogItem( "Report",$reportName,$targetreportLibrary,$true,$reportContent,$null,[ref] $warnings ) 
           $Message = "Deployed report $reportName to  $targetreportLibrary .."
           $Message  | out-file -Filepath $logfile -append
            }    
      Catch
           {
           $Message  =  "Error: Could not deploy $reportName to " +  $targetreportLibrary + ". "+ $_.Exception.Message 
           $Message  | out-file -Filepath $logfile -append
"-------------------------End of $reportName--------------------------------------" |  out-file -Filepath $logfile -append
$isSuccess = 0
           }

#Extract the shared datasources and apply them on report.
# Shared datasource name in .rdl file should exactly be same as that of shared dataset deployed in the server.
    $reportAbsoluteUrl = [string]::Concat($targetreportLibrary.TrimEnd("/"),"/",$reportName)
           $Message  =  "Setting up shared DataSource(s) "
           $Message | out-file -Filepath $logfile -append
    $dataSources = $rs.GetItemDataSources($reportAbsoluteUrl) 
           $dataSources | ForEach-Object  {
           $sharedDataSourceUrl = $DatasourceLibrary  +$_.name
           $proxyNamespace = $_.GetType().Namespace
           $dataSource = New-Object ("$proxyNamespace.DataSource")
           $dataSource.Name = $_.name 
           $dataSource.Item = New-Object ("$proxyNamespace.DataSourceReference")
           $dataSource.Item.Reference = $sharedDataSourceUrl

           $_.item = $dataSource.Item
                Try 
           {
           $rs.SetItemDataSources( $reportAbsoluteUrl,  $_)
           $Message =  "Set Shared DataSource "+  $dataSource.Name   
           $Message  | out-file -Filepath $logfile -append
           }
               Catch [System.Exception]
           {
           $Message =  "Error: Could not fix DataSource " + $dataSource.Name + "."+ $_.Exception.Message  
           $Message  | out-file -Filepath $logfile -append
"-------------------------End of $reportName--------------------------------------" |  out-file -Filepath $logfile -append	
            $isSuccess = 0

           }
         }
                                
#Extract the shared datasets and apply them on report
# Shared datasets name in .rdl file should exactly be same as that of shared dataset deployed in the server.
          $Message  =  "Setting up shared DataSet(s) "
          $Message | out-file -Filepath $logfile -append
          $dataSets = $rs.GetItemReferences($reportAbsoluteUrl, 'DataSet') 
          $dataSets | ForEach-Object  {		
          $sharedDataSetUrl = $DatasetLibrary  +$_.name + ".rsd"
          $DatasetLibrary  +$_.name + ".rsd"
          $dataSet = New-Object ("$proxyNamespace.ItemReference")
          $dataSet.Name = $_.name
          $dataSet.Reference = $sharedDataSetUrl
          Try 
            {
	 	   $rs.SetItemReferences( $reportAbsoluteUrl,  $dataSet)  
           $Message  = "Set Shared DataSet " + $dataSet.Name  
           $Message  | out-file -Filepath $logfile -append
            }
          Catch
           {
           $Message =  "Error: Could not fix DataSet " + $dataSet.Name +"."+ $_.Exception.Message 
           $Message  | out-file -Filepath $logfile -append
"-------------------------End of $reportName--------------------------------------" |  out-file -Filepath $logfile -append
$isSuccess = 0
   
            }
	} 
"-------------------------End of $reportName--------------------------------------" |  out-file -Filepath $logfile -append
}
	 
}                            
"-------------------------End of Generic Powershell to deploy SSRS reports to Report server---------------------------------" |  out-file -Filepath $logfile -append
return $isSuccess


                                                                

                                        
        

