﻿Param
(
$LogFilePath,
$FolderPath
)

#Param
#############################################################################################
$ServerName = "Server Instance Name"
$SSISCatalog = "SSISDB"
############################################################################################
$isSuccess = 1
$ssisfiles = Get-ChildItem  $FolderPath -Recurse | where-object {$_.extension  -eq ".ispac"}
Try
{
if ($ssisfiles)
{
  # deploying many reports so iterate through the files
  foreach($ssisfile in $ssisfiles.FullName) 
  {

    $relativePath = Get-Item $ssisfile | Resolve-Path 
    $LocalSSISreference = $ssisfile
    $SSISFileInfo = Get-Item ($LocalSSISreference);
    $SSISProjectName = $SSISFileInfo.Name;	

"-------------------------Start of $SSISProjectName--------------------------------------" |  out-file -Filepath $logfile -append
    $FolderName = Split-Path( $relativePath | split-path  -Parent )-Leaf

$ProjectFilePath = "$relativePath"


$ProjectFilePath   |  out-file -Filepath $logfile -append
$ISNamespace = "Microsoft.SqlServer.Management.IntegrationServices"
# Load the IntegrationServices Assembly
[Reflection.Assembly]::LoadWithPartialName($ISNamespace)
# Create a connection to the server
$sqlConnectionString = "Data Source=$ServerName;Initial Catalog=master;Integrated Security=SSPI;"
$sqlConnection = New-Object System.Data.SqlClient.SqlConnection 

$sqlConnection.ConnectionString = $sqlConnectionString
$integrationServices = New-Object "$ISNamespace.IntegrationServices" $sqlConnection

$catalog = $integrationServices.Catalogs[$SSISCatalog]

# Create the Integration Services object if it does not exist
if (!$catalog) {
    # Provision a new SSIS Catalog
    "SSIS catalog does not exist, please create it first and then replay the deployment"|  out-file -Filepath $logfile -append
  $isSuccess = 0
}

$folder = $catalog.Folders[$FolderName]

if (!$folder)
{
    #Create a folder in SSISDB
    "$FolderName folder does not exist, creating it ..." |  out-file -Filepath $logfile -append
    $folder = New-Object "$ISNamespace.CatalogFolder" ($catalog, $FolderName, $FolderName)            
    $folder.Create()  
}

# deploy project to the folder
[byte[]] $projectFile = [System.IO.File]::ReadAllBytes($LocalSSISreference)
$folder.DeployProject($SSISProjectName.replace(".ispac",""), $projectFile)


#$project.Alter()  

}
}
}
Catch
{
             "Error: $_.Exception.Message"  | out-file -Filepath $logfile -append
		$isSuccess = 0
}
Return $isSuccess
##end of script

